==> nextcloud-app-spreed-1%3A10.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/spreed/l10n/mn.js <==
OC.L10N.register(
    "spreed",
    {
    "Guest" : "Зочин",
    "Everyone" : "Бүх хэрэглэгчид",
    "Save changes" : "Өөрчлөлтийг хадгалах",
    "Saved!" : "Хадгалагдлаа!",
    "None" : "юу ч үгүй",
    "User" : "Хэрэглэгч",
    "Disabled" : "идэвхигүй",
    "Users" : "хэрэглэгч",
    "Name" : "Нэр",
    "Language" : "Хэл",
    "Country" : "Улс",
    "Status" : "төлөв",
    "Created at" : "үүсгэгдсэн",
    "Pending" : "Хүлээгдэж байгаа",
    "Error" : "Алдаа",
    "Blocked" : "Хаагдсан",
    "Saved" : "Хадгалах",
    "Dismiss" : "Арилгах",
    "Back" : "буцах",
    "Favorite" : "Дуртай",
    "Remove from favorites" : "Remove from favorites",
    "Add to favorites" : "Add to favorites",
    "Loading" : "Loading",
    "Groups" : "бүлэгүүд",
    "Circles" : "Тойрог",
    "Settings" : "Тохиргоо",
    "Password protect" : "Нууц үгээр хамгаалах",
    "Close" : "Хаах",
    "Reply" : "хариулт",
    "Remove" : "Устгах",
    "Today" : "өнөөдөр",
    "Yesterday" : "өчигдөр",
    "Enabled" : "Идэвхижүүлэх",
    "Save" : "Хадгалах",
    "Password" : "Нууц үг",
    "Login" : "Нэвтрэх",
    "Nickname" : "Товч нэр",
    "No results" : "Үр дүн байхгүй",
    "Add users or groups" : "Add users or groups",
    "Edit" : "засварлах",
    "Search" : "Хайх",
    "Share link" : "Холбоос хуваалцах",
    "Password protection" : "Password protection",
    "Enter a password" : "Enter a password",
    "Copy" : "Хуулах",
    "Copied!" : "Хуулсан!",
    "Not supported!" : "Дэмжигдэхгүй",
    "Press ⌘-C to copy." : "Хуулахын тулд ⌘-C дарна уу.",
    "Press Ctrl-C to copy." : "Хуулахын тулд Ctrl-C дарна уу.",
    "Cancel" : "болиулах",
    "Submit" : "мэдэгдэх",
    "Change password" : "Нууц үг солих",
    "Rename" : "Нэрлэнэ үү",
    "Send" : "илгээх",
    "Share" : "Түгээх",
    "Error while sharing" : "Түгээхэд алдаа гарлаа",
    "Contacts" : "Харилцагчид"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-spreed-1%3A10.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/spreed/l10n/mn.js <==
OC.L10N.register(
    "spreed",
    {
    "Guest" : "Зочин",
    "Everyone" : "Бүх хэрэглэгчид",
    "Save changes" : "Өөрчлөлтийг хадгалах",
    "Saved!" : "Хадгалагдлаа!",
    "None" : "юу ч үгүй",
    "User" : "Хэрэглэгч",
    "Disabled" : "идэвхигүй",
    "Users" : "хэрэглэгч",
    "Name" : "Нэр",
    "Language" : "Хэл",
    "Country" : "Улс",
    "Status" : "төлөв",
    "Created at" : "үүсгэгдсэн",
    "Pending" : "Хүлээгдэж байгаа",
    "Error" : "Алдаа",
    "Blocked" : "Хаагдсан",
    "Saved" : "Хадгалах",
    "Dismiss" : "Арилгах",
    "Favorite" : "Дуртай",
    "Remove from favorites" : "Remove from favorites",
    "Add to favorites" : "Add to favorites",
    "Loading" : "Loading",
    "Groups" : "бүлэгүүд",
    "Circles" : "Тойрог",
    "Settings" : "Тохиргоо",
    "Password protect" : "Нууц үгээр хамгаалах",
    "Back" : "буцах",
    "Close" : "Хаах",
    "Reply" : "хариулт",
    "Remove" : "Устгах",
    "Today" : "өнөөдөр",
    "Yesterday" : "өчигдөр",
    "Enabled" : "Идэвхижүүлэх",
    "Save" : "Хадгалах",
    "Password" : "Нууц үг",
    "Login" : "Нэвтрэх",
    "Nickname" : "Товч нэр",
    "No results" : "Үр дүн байхгүй",
    "Add users or groups" : "Add users or groups",
    "Edit" : "засварлах",
    "Search" : "Хайх",
    "Share link" : "Холбоос хуваалцах",
    "Password protection" : "Password protection",
    "Enter a password" : "Enter a password",
    "Send" : "илгээх",
    "Contacts" : "Харилцагчид",
    "Cancel" : "болиулах",
    "Submit" : "мэдэгдэх"
},
"nplurals=2; plural=(n != 1);");
